@@ -22,6 +22,9 @@
 #include "VolumeAdjustment.h"
 #include "Global.h"
 
+#include <limits>
+#include <type_traits>
+
 #include <QSignalBlocker>
 #include <QtCore/QMutexLocker>
 #include <QtGui/QImageWriter>
@@ -605,8 +608,8 @@ QString Log::imageToImg(const QByteArray &format, const QByteArray &image) {
 }
 
 QString Log::imageToImg(QImage img, int maxSize) {
-	constexpr int MAX_WIDTH  = 600;
-	constexpr int MAX_HEIGHT = 400;
+	constexpr int MAX_WIDTH  = 1600;
+	constexpr int MAX_HEIGHT = 1000;
 
 	if ((img.width() > MAX_WIDTH) || (img.height() > MAX_HEIGHT)) {
 		img = img.scaled(MAX_WIDTH, MAX_HEIGHT, Qt::KeepAspectRatio, Qt::SmoothTransformation);
@@ -672,7 +675,7 @@ QString Log::validHtml(const QString &html, QTextCursor *tc) {
 	qtd.adjustSize();
 	QSizeF s = qtd.size();
 
-	if (!s.isValid()) {
+	if (!s.isValid() || s.width() == 0 || s.height() == 0) {
 		QString errorInvalidSizeMessage = tr("[[ Invalid size ]]");
 		if (tc) {
 			tc->insertText(errorInvalidSizeMessage);
@@ -682,10 +685,14 @@ QString Log::validHtml(const QString &html, QTextCursor *tc) {
 		}
 	}
 
-	int messageSize = static_cast< int >(s.width() * s.height());
-	int allowedSize = 2048 * 2048;
+	static constexpr unsigned int allowedSize = 2048 * 2048;
+	// This checks against negative sizes as well as sizes whose product overflows the integral type we use to represent
+	// the maximum allowed size
+	const bool saneSize =
+		s.width() > 0 && s.height() > 0 && s.width() < std::numeric_limits< decltype(allowedSize) >::max() / s.height();
+	const auto messageSize = static_cast< std::decay_t< decltype(allowedSize) > >(s.width() * s.height());
 
-	if (messageSize > allowedSize) {
+	if (!saneSize || messageSize > allowedSize) {
 		QString errorSizeMessage = tr("[[ Text object too large to display ]]");
 		if (tc) {
 			tc->insertText(errorSizeMessage);
@@ -707,6 +714,15 @@ QString Log::validHtml(const QString &html, QTextCursor *tc) {
 
 void Log::log(MsgType mt, const QString &console, const QString &terse, bool ownMessage, const QString &overrideTTS,
 			  bool ignoreTTS) {
+	if (QThread::currentThread() != thread()) {
+		// Invoke in main thread in order to keep the Qt gods on our side by not calling any UI
+		// functions from a separate thread (can lead to program crashes)
+		QMetaObject::invokeMethod(this, "log", Qt::QueuedConnection, Q_ARG(Log::MsgType, mt),
+								  Q_ARG(const QString &, console), Q_ARG(const QString &, terse),
+								  Q_ARG(bool, ownMessage), Q_ARG(const QString &, overrideTTS), Q_ARG(bool, ignoreTTS));
+		return;
+	}
+
 	QDateTime dt = QDateTime::currentDateTime();
 
 	int ignore = qmIgnore.value(mt);
